@@ -16,6 +16,7 @@
  */
 
 #include "jfs.h"
+#include "FileSystem.h"
 #include "Partition.h"
 
 namespace GParted
@@ -68,8 +69,8 @@ FS jfs::get_filesystem_support()
 		fs .online_grow = fs .grow ;
 #endif
 
-	fs .MIN = 16 * MEBIBYTE ;
-	
+	fs_limits.min_size = 16 * MEBIBYTE;
+
 	return fs ;
 }
 
