@@ -16,6 +16,7 @@
  */
 
 #include "ntfs.h"
+#include "FileSystem.h"
 #include "OperationDetail.h"
 #include "Partition.h"
 #include "Utils.h"
@@ -115,7 +116,7 @@ FS ntfs::get_filesystem_support()
 	//Minimum NTFS partition size = (Minimum NTFS volume size) + (backup NTFS boot sector)
 	//                            = (1 MiB) + (1 sector)
 	// For GParted this means 2 MiB because smallest GUI unit is MiB.
-	fs. MIN = 2 * MEBIBYTE;
+	fs_limits.min_size = 2 * MEBIBYTE;
 
 	return fs ;
 }
@@ -215,7 +216,7 @@ bool ntfs::create( const Partition & new_partition, OperationDetail & operationd
 
 bool ntfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
-	bool return_value = false ;
+	bool success;
 	Glib::ustring size = "" ;
 	if ( ! fill_partition )
 	{
@@ -226,33 +227,19 @@ bool ntfs::resize( const Partition & partition_new, OperationDetail & operationd
 
 	//simulation..
 	operationdetail .add_child( OperationDetail( _("run simulation") ) ) ;
+	success = ! execute_command( cmd + " --no-action " + Glib::shell_quote( partition_new.get_path() ),
+	                             operationdetail.get_last_child(), EXEC_CHECK_STATUS );
+	operationdetail.get_last_child().set_success_and_capture_errors( success );
+	if ( ! success )
+		return false;
 
-	if ( ! execute_command( cmd + " --no-action " + Glib::shell_quote( partition_new.get_path() ),
-	                        operationdetail.get_last_child(), EXEC_CHECK_STATUS ) )
-	{
-		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
-
-		//real resize
-		operationdetail .add_child( OperationDetail( _("real resize") ) ) ;
-
-		if ( ! execute_command( cmd + " " + Glib::shell_quote( partition_new.get_path() ),
-		                        operationdetail.get_last_child(), EXEC_CHECK_STATUS|EXEC_PROGRESS_STDOUT,
-		                        static_cast<StreamSlot>( sigc::mem_fun( *this, &ntfs::resize_progress ) ) ) )
-		{
-			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
-			return_value = true ;
-		}
-		else
-		{
-			operationdetail .get_last_child() .set_status( STATUS_ERROR ) ;
-		}
-	}
-	else
-	{
-		operationdetail .get_last_child() .set_status( STATUS_ERROR ) ;
-	}
-	
-	return return_value ;
+	// Real resize
+	operationdetail.add_child( OperationDetail( _("real resize") ) );
+	success = ! execute_command( cmd + " " + Glib::shell_quote( partition_new.get_path() ),
+		                     operationdetail.get_last_child(), EXEC_CHECK_STATUS|EXEC_PROGRESS_STDOUT,
+		                     static_cast<StreamSlot>( sigc::mem_fun( *this, &ntfs::resize_progress ) ) );
+	operationdetail.get_last_child().set_success_and_capture_errors( success );
+	return success;
 }
 
 bool ntfs::copy( const Partition & src_part,
