@@ -16,9 +16,9 @@
  */
 
 #include "xfs.h"
+#include "FileSystem.h"
 #include "OperationDetail.h"
 #include "Partition.h"
-#include "ProgressBar.h"
 #include "Utils.h"
 
 #include <glibmm/ustring.h>
@@ -80,8 +80,9 @@ FS xfs::get_filesystem_support()
 		fs .online_grow = fs .grow ;
 #endif
 
-	fs .MIN = 32 * MEBIBYTE ;//official minsize = 16MB, but the smallest xfs_repair can handle is 32MB...
-	
+	// Official minsize = 16MB, but the smallest xfs_repair can handle is 32MB.
+	fs_limits.min_size = 32 * MEBIBYTE;
+
 	return fs ;
 }
 
